<?php

class Imagick
{
  var $source_path = '';
  var $image_data = array();
  var $imagemagickdir = '';
  var $commands = array();

  const INTERLACE_NO = 'none';
  const INTERLACE_LINE = 'line';
  const INTERLACE_PLANE = 'plane';
  const INTERLACE_PARTITION = 'partition';
  const INTERLACE_GIF = 'GIF';
  const INTERLACE_JPEG = 'JPEG';
  const INTERLACE_PNG = 'PNG';

  const FILTER_POINT = 'Point';
  const FILTER_BOX = 'Box';
  const FILTER_TRIANGLE = 'Triangle';
  const FILTER_HERMITE = 'Hermite';
  const FILTER_HANNING = 'Hanning';
  const FILTER_HAMMING = 'Hamming';
  const FILTER_BLACKMAN = 'Blackman';
  const FILTER_GAUSSIAN = 'Gaussian';
  const FILTER_QUADRATIC = 'Quadratic';
  const FILTER_CUBIC = 'Cubic';
  const FILTER_CATROM = 'Catrom';
  const FILTER_MITCHELL = 'Mitchell';
  const FILTER_LANCZOS = 'Lanczos';
  const FILTER_BESSEL = 'Bessel';
  const FILTER_SINC = 'Sinc';

  const ORIENTATION_TOPLEFT = 'top-left';
  const ORIENTATION_TOPRIGHT = 'top-right';
  const ORIENTATION_BOTTOMRIGHT = 'bottom-right';
  const ORIENTATION_BOTTOMLEFT = 'bottom-left';
  const ORIENTATION_LEFTTOP = 'left-top';
  const ORIENTATION_RIGHTTOP = 'right-top';
  const ORIENTATION_RIGHTBOTTOM = 'right-bottom';
  const ORIENTATION_LEFTBOTTOM = 'left-bottom';

  function __construct($source)
  {
    global $conf;

    $this->source_path = $source;

    if (isset($conf['imagick_dir']))
      $this->imagemagickdir = rtrim($conf['imagick_dir'], ' /\\').'/';

    $command = $this->imagemagickdir."identify -verbose ".realpath($this->source_path);
    @exec($command, $returnarray, $returnvalue);
    if($returnvalue)
    {
      die("ImageMagick: Corrupt image");
    }
    else
    {
      foreach($returnarray as $value)
      {
        $arr = explode(':', $value, 2);
        if (count($arr) == 2)
        {
          $this->image_data[trim($arr[0])] = trim($arr[1]);
        }
      }
    }
  }

  function add_command($command, $params=null)
  {
    $this->commands[$command] = $params;
  }

  function getImageWidth()
  {
    preg_match('#^(\d+)x#', $this->image_data['Geometry'], $match);
    return isset($match[1]) ? $match[1] : false;
  }

  function getImageHeight()
  {
    preg_match('#^\d+x(\d+)(?:\+|$)#', $this->image_data['Geometry'], $match);
    return isset($match[1]) ? $match[1] : false;
  }

  function setImageCompressionQuality($quality)
  {
    $this->add_command('quality', $quality);
  }

  function setInterlaceScheme($interlace)
  {
    $this->add_command('interlace', $interlace);
  }

  function resizeImage($width, $height, $filter, $blur)
  {
    $this->add_command('resize', $width.'x'.$height.'!');
    $this->add_command('filter', $filter);
    //$this->add_command('blur', $blur);
  }

  function stripImage()
  {
    $this->add_command('strip');
  }

  function rotateImage($background, $rotate)
  {
    $this->add_command('rotate', $rotate);
  }

  function setImageOrientation($orientation)
  {
    $this->add_command('orient', $orientation);
  }

  function cropImage($width, $height, $x, $y)
  {
    $this->add_command('crop', $width.'x'.$height.'+'.$x.'+'.$y);
  }

  function writeImage($destination_filepath)
  {
    global $conf;

    $exec = $this->imagemagickdir.'convert';
    $exec .= ' '.realpath($this->source_path);

    foreach ($this->commands as $command => $params)
    {
      $exec .= ' -'.$command;
      if (!empty($params))
      {
        $exec .= ' '.$params;
      }
    }

    $dest = pathinfo($destination_filepath);
    $exec .= ' '.realpath($dest['dirname']).'/'.$dest['basename'];
    @exec($exec, $returnarray, $returnvalue);
  }

  function destroy()
  {
    @unlink($this->tmp_path);
    return true;
  }
}

class ImagickPixel { }

?>